<?php

namespace Litecms\BenefitCard\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use Litecms\BenefitCard\Http\Requests\RequestformAdminApiRequest;
use Litecms\BenefitCard\Interfaces\RequestformRepositoryInterface;
use Litecms\BenefitCard\Models\Requestform;

/**
 * Admin API controller class.
 */
class RequestformAdminApiController extends AdminController
{
    /**
     * Initialize requestform controller.
     *
     * @param type RequestformRepositoryInterface $requestform
     *
     * @return type
     */
    public function __construct(RequestformRepositoryInterface $requestform)
    {
        $this->repository = $requestform;
        parent::__construct();
    }

    /**
     * Display a list of requestform.
     *
     * @return json
     */
    public function index(RequestformAdminApiRequest $request)
    {
        $requestforms  = $this->repository
            ->setPresenter('\\Litecms\\BenefitCard\\Repositories\\Presenter\\RequestformListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $requestforms['code'] = 2000;
        return response()->json($requestforms) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display requestform.
     *
     * @param Request $request
     * @param Model   Requestform
     *
     * @return Json
     */
    public function show(RequestformAdminApiRequest $request, Requestform $requestform)
    {
        $requestform         = $requestform->presenter();
        $requestform['code'] = 2001;
        return response()->json($requestform)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new requestform.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(RequestformAdminApiRequest $request, Requestform $requestform)
    {
        $requestform         = $requestform->presenter();
        $requestform['code'] = 2002;
        return response()->json($requestform)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new requestform.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(RequestformAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $requestform          = $this->repository->create($attributes);
            $requestform          = $requestform->presenter();
            $requestform['code']  = 2004;

            return response()->json($requestform)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show requestform for editing.
     *
     * @param Request $request
     * @param Model   $requestform
     *
     * @return json
     */
    public function edit(RequestformAdminApiRequest $request, Requestform $requestform)
    {
        $requestform         = $requestform->presenter();
        $requestform['code'] = 2003;
        return response()-> json($requestform)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the requestform.
     *
     * @param Request $request
     * @param Model   $requestform
     *
     * @return json
     */
    public function update(RequestformAdminApiRequest $request, Requestform $requestform)
    {
        try {

            $attributes = $request->all();

            $requestform->update($attributes);
            $requestform         = $requestform->presenter();
            $requestform['code'] = 2005;

            return response()->json($requestform)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the requestform.
     *
     * @param Request $request
     * @param Model   $requestform
     *
     * @return json
     */
    public function destroy(RequestformAdminApiRequest $request, Requestform $requestform)
    {

        try {

            $t = $requestform->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('benefit_card::requestform.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
