<?php

namespace Litecms\BenefitCard\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Litecms\BenefitCard\Interfaces\RequestformRepositoryInterface;
use Litecms\BenefitCard\Repositories\Presenter\RequestformItemTransformer;

/**
 * Pubic API controller class.
 */
class RequestformPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Litecms\Requestform\Interfaces\RequestformRepositoryInterface $requestform
     *
     * @return type
     */
    public function __construct(RequestformRepositoryInterface $requestform)
    {
        $this->repository = $requestform;
        parent::__construct();
    }

    /**
     * Show requestform's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $requestforms = $this->repository
            ->setPresenter('\\Litecms\\BenefitCard\\Repositories\\Presenter\\RequestformListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $requestforms['code'] = 2000;
        return response()->json($requestforms)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show requestform.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $requestform = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($requestform)) {
            $requestform         = $this->itemPresenter($module, new RequestformItemTransformer);
            $requestform['code'] = 2001;
            return response()->json($requestform)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
