<?php

namespace Litecms\BenefitCard\Http\Requests;

use App\Http\Requests\Request as FormRequest;
use Illuminate\Http\Request;

class RequestformUserApiRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(Request $request)
    {
        $requestform = $this->route('requestform');
        if (is_null($requestform)) {
            // Determine if the user is authorized to access requestform module,
            return $request->user('api')->canDo('benefit_card.requestform.view');
        }

        if ($request->isMethod('POST') || $request->is('*/create')) {
            // Determine if the user is authorized to create an entry,
            return $request->user('api')->can('create', $requestform);
        }

        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            // Determine if the user is authorized to update an entry,
            return $request->user('api')->can('update', $requestform);
        }

        if ($request->isMethod('DELETE')) {
            // Determine if the user is authorized to delete an entry,
            return $request->user('api')->can('delete', $requestform);
        }

        // Determine if the user is authorized to view the module.
        return $request->user('api')->can('view', $requestform);

    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        if ($request->isMethod('POST')) {
            // validation rule for create request.
            return [
                'first_name'          => 'required',
                'last_name'           => 'required',
                'mobile'              => 'required',
                'email'               => 'required',
                'area'                => 'required',
                'street_address'      => 'required',
                'area'                => 'required',
                'building_number'     => 'required',
                'appartment_number'   => 'required',
            ];
        }
        
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            // Validation rule for update request.
            return [
                'first_name'          => 'required',
                'last_name'           => 'required',
                'mobile'              => 'required',
                'email'               => 'required',
                'area'                => 'required',
                'street_address'      => 'required',
                'area'                => 'required',
                'building_number'     => 'required',
                'appartment_number'   => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
