<?php

namespace Litecms\BenefitCard\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Litecms\BenefitCard\Models\Requestform;

class RequestformPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the requestform.
     *
     * @param User $user
     * @param Requestform $requestform
     *
     * @return bool
     */
    public function view(User $user, Requestform $requestform)
    {
        if ($user->canDo('benefit_card.requestform.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $requestform->user_id;
    }

    /**
     * Determine if the given user can create a requestform.
     *
     * @param User $user
     * @param Requestform $requestform
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('benefit_card.requestform.create');
    }

    /**
     * Determine if the given user can update the given requestform.
     *
     * @param User $user
     * @param Requestform $requestform
     *
     * @return bool
     */
    public function update(User $user, Requestform $requestform)
    {
        if ($user->canDo('benefit_card.requestform.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $requestform->user_id;
    }

    /**
     * Determine if the given user can delete the given requestform.
     *
     * @param User $user
     * @param Requestform $requestform
     *
     * @return bool
     */
    public function destroy(User $user, Requestform $requestform)
    {
        if ($user->canDo('benefit_card.requestform.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $requestform->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
